---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2021-07-29;108
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20210730&codiceRedaz=21G00118&dataVigenza=20251104
dataGU: 20210730
codiceRedaz: 21G00118
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 31 maggio 2021, n. 77, recante governance del Piano nazionale di ripresa e resilienza e prime misure di rafforzamento delle strutture amministrative e di accelerazione e snellimento delle procedure. (21G00118)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 31 maggio 2021, n. 77, recante governance del Piano nazionale di ripresa e resilienza e prime misure di rafforzamento delle strutture amministrative e di accelerazione e snellimento delle procedure, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. Al fine di monitorare l'efficace attuazione dei progetti previsti dal Piano nazionale di ripresa e resilienza (PNRR) e il rispetto dei termini entro i quali i progetti medesimi devono essere completati sulla base del calendario concordato con le istituzioni europee, il Governo fornisce alle Commissioni parlamentari competenti le informazioni e i documenti utili per esercitare il controllo sull'attuazione del PNRR e del Piano nazionale per gli investimenti complementari al PNRR di cui al decreto-legge 6 maggio 2021, n. 59, convertito, con modificazioni, dalla legge 1° luglio 2021, n. 101.

3. Il Governo fornisce altresi' alle Commissioni parlamentari competenti i dati, gli atti, le informazioni e i documenti necessari allo svolgimento dei loro compiti, anche al fine di prevenire, di rilevare e di correggere eventuali criticita' relative all'attuazione del PNRR.

4. Il Governo trasmette, inoltre, alle Commissioni parlamentari competenti i documenti, riguardanti le materie di competenza delle medesime, inviati agli organi dell'Unione europea relativamente all'attuazione del PNRR.

5. Sulla base delle informazioni ricevute e dell'attivita' istruttoria svolta, anche in forma congiunta, con le modalita' definite dalle intese di cui al comma 7, le Commissioni parlamentari competenti:

- a) monitorano lo stato di realizzazione del PNRR e i progressi compiuti nella sua attuazione, anche con riferimento alle singole misure, con particolare attenzione al rispetto e al raggiungimento degli obiettivi inerenti alle priorita' trasversali del medesimo Piano, quali il clima, il digitale, la riduzione dei divari territoriali, la parita' di genere e i giovani;
- b) formulano osservazioni ed esprimono valutazioni utili ai fini della migliore attuazione del PNRR nei tempi previsti.

6. Le Camere possono stipulare con il Ministero dell'economia e delle finanze una convenzione per disciplinare le modalita' di fruizione dei dati di monitoraggio rilevati dal Sistema informativo unitario «ReGiS».

7. I Presidenti della Camera dei deputati e del Senato della Repubblica, al fine di favorire lo svolgimento congiunto dell'attivita' istruttoria utile al controllo parlamentare e di potenziare la capacita' di approfondimento dei profili tecnici della contabilita' e della finanza pubblica da parte delle Commissioni parlamentari competenti, adottano intese volte a promuovere le attivita' delle Camere, anche in forma congiunta, nonche' l'integrazione delle attivita' svolte dalle rispettive strutture di supporto tecnico.

8. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

